//  
//      aster3.cpp - Compute the megatonage required to melt and vaporize
//                   an asteroid of specified diameter. For an irregular
//                   asteroid of volume V, use the equivilant
//                   diameter  d = 2(3V/4*pi)**(1/3).
//
//                   OUTPUT FILE: aster3.txt in same directory, a screen trace.  Oct,2001.
//
//                   In addition, compute the asteroid equivilant megatonage,
//                   Richter magnitude M from the total energy,
//                   crater size, ejectae mass, earth crust penetration,
//                   and earth-covering dust carpet thickeness,
//                   the extinction blanket. WHEN WORLDS COLLIDE.(old sci-fi)
//                   Include rock stattering thresholds and ice shattering
//                   threshold for a model comet made of regular ice.
//                   Comet nuclei are 1-10 km in width.
//
//                   Note that the strategy of chipping away at an asteroid
//                   with N smaller explosions of energy E such that
//			E_Fujiwara_catastrophic_shattering = NE
//                   will destroy an asteroid as easily as NE delivered all
//                   at once.
//            
//                   aster2.exe includes the reactant weight calculation
//                   for deuterium-tritium reactants and the number of
//                   space shuttle flights required to transport an
//                   adequate volume of reactants into orbit to support
//                   the manuever. Deuterium-Tritium features 12.5 Kg/MT
//                   (correction: 12.39 Kg/MT : 1/24/99 )
//                   and the space shuttle can transport 27.5 tons per flight.
//
//                   I find [See Robert A. Gross, FUSION ENERGY, John Wiley]:
//
//                    Deuterium-Tritium   12.39 kg/megaton,(lowest ignition T)
//                    Deuterium-Deuterium 12.1 kg/megaton,
//                    Hydrogen-Lithium-6  29.23 kg/megaton,
//                    Hydrogen-2Lithium-6 27.26 kg/megaton.
//
//                   Pure Lithium is 6.42% Lithium-6, and 92.58% is
//                   Lithium-7, which reacts faintly endothermically
//                   with hydrogen. Deuterium-Tritium ignites at the lowest
//                   temperature.
//
//                   An alternative is to chip away at the asteroid with
//                   many explosions over a long time period.
//
//                                                     - James A. Green
//                                                       December 30, 1998
//      
//
//         It seems to me that the best way to destroy an asteroid
//      or a large meteor closing in on earth is to intercept and
//      hit it with nuclear weapons. Probably the most effective
//      method would seize it with something like a pair of pliers,
//      to pulverize it.  The focused shock wave technique of placing
//      the asteroid between a pair of bombs exploded simultaneously
//      on opposite sides of the asteroid seems to offer the best
//      guarantee of success. A higher megatonage might be used to scatter
//      the debris to avoid radioactive fallout in the atmosphere.
//      The whole process should take place as far from Earth as
//      can be arranged.  For larger asteroids, N bombs must be used
//      such that the total bomb energy NE equals the destruction energy.
//         Conservatively, an adequate blast amplitude should be the
//      megatonage equivilant of the energy required to vaporize the
//      asteroid.  Each bomb in a pair used to shatter the object
//      would then have this 1/2 megatonage, which is actually
//      an overestimate. The bombs should be firmly mounted in the surface
//      of the asteroid so that they have a good grip on their environment.
//      Mounting might occur via drilling or a rock-penetrating heavy element
//      weighted warhead akin to an armour-piercing shell.  The drilling
//      method is the most conservative. The more deeply mounted, the better.
//          The vaporization energy of steel and other materials is
//      not publicly available, but we can estimate it by multiplying
//      the boiling point of iron at 3023.15 degrees Kelvin by the
//      specific heat of iron, 0.1075 calories per gram per degree
//      Kelvin. This yeilds 325 calories per gram of iron, or
//      1360 Joules per gram of iron, 1.36 x 10**6 Joules per Kg.    
//      1 Megaton equals 4.184 x 10**15 Joules,  and iron pyrites
//      have a density of 5 grams per cm**3, or 5000 Kg per cubic meter.
//      This means 1 Megaton boils 4.184x10**15/1.36x10**6 Kg
//      of iron pyrites. That is, 3.076x10**9 Kg/Megaton of pyrites
//      may be boiled per Megaton.  Since pyrites have a density
//      of 5000 Kg/m**3, 0.615x10**6 cubic meters of pyrite asteroid
//      may be boiled per megaton.
//           The melting point for pure iron is also a good measure for
//      this promblem, and I note that the boiling point for iron differs
//      very little from the iron pyrite boiling temperature. The element
//      iron has a melting point of 1811 degrees Kelvin. Using the specific
//      heat 449 Joules/Kg per degree Kelvin, 1811*449 = 813139 J/Kg are
//      required to melt iron.  Since 1 MT = 4.184x10**15 Joules, we
//      find that the melting coefficient for iron is 5.145x10**9 Kg/MT.
//      A Megaton will melt more iron than it will boil. 
//         
//
//  MELTING AND BOILING VAPORIZATION PARAMETERS FOR KEY ELEMENTS
//                                                    Approximated
// Element    Melting   Boiling  Heat Capacity  Boil Energy  Boiling Coeff.
//             Temp (K)   Temp (K)    J/Kg*K        J/Kg     Kg/Megaton
// Silicon    1687       3540        705      2.4957x10**6  1.6765x10**9
// Aluminum    934       2793        897      2.5053x10**6  1.6700x10**9
// Iron       1811       3135        449      1.4076x10**6  2.9724x10**9
// Tungsten   3695       5828        132      0.7693x10**6  5.4387x10**9
// Platinum   2042       4100        133      0.5453x10**6  7.6728x10**9
// Zirconium  2128       4682        278      1.3016x10**6  3.2145x10**9
//
// COMPOSITION OF THE EARTH'S CRUST  &  THE ROLE OF SILICON DIOXIDE
//   1st   Oxygen    4.64x10**5 mg/Kg
//   2nd   Silicon   2.82x10**5 mg/Kg   Silicon dioxide is 59.14% of igneous
//   3rd   Aluminum  8.32x10**4 mg/Kg   rock, 58.10% of average shale,
//   4th   Iron      5.63x10**4 mg/Kg   78.33% of average sandstone,
//                                      57.95% of average sediment.
//                           (See the CRC HANDBOOK OF CHEMISTRY & PHYSICS)
//    
//          Our program has the user entering the asteroid diameter.
//      If we assume that it is made of iron pyrites, then the
//      megatonage required for the boiling of the asteroid per
//      bomb in a 2-bomb pincher is conservatively
//
//       (1/2)*(5000[ (4/3)*pi*R**3 ]/3.076x10**9)  megatons per bomb.
//
//      Similarly, the megatonage to melt an iron asteroid with a two-
//      bomb pincher is
//
//      (1/2)*(5000[ (4/3)*pi*R**3 ]/5.145x10**9) megatons per bomb.
//
//
//        To blow a stone asteroid to bits requires a fragmentation energy
//     E/M > 10**8 in ergs per gram according to rocky target experiments.
//     Choosing E/M = 5x10**8 is an experimentally explored choice yeilding
//     fragments with 0.01 to 0.001 Mtotal for stone composition asteroids
//     if the devices are properly imbedded. This procedure yeilds lowest
//     total megatonage for an asteroid, but I think a boiling energy
//     or greater energy approach is safer and more conservative yet.
//     Mere fragmentation produces maybe dangerous asteroid shrapnel. Higher
//     energies produce safer flakes but perhaps more dangerous radiation
//     which terrestrial atmosphere screens out well, however.      
//        See A. Fujiwara, et.al., "Experiments and Scaling Laws for
//         Catastrophic Collisions", in ASTEROIDS II,
//         edited by Binzel, Gehrels, and Matthews.
//
//     The Fujiwara-Tsukamoto ejectae energy after the explosion for
//     the asteroid fragments is, from their experiments,
//
//         V = 3.2x10**-5 (E/M)**0.76 cm/sec, using cgs units.
//
//     Let Mx/Ex be given in Kilograms per Megaton. Then, in MKS units,
//     
// V = (1/100)*3.2x10**-5 {[(Mx/Ex)**-1]*(4.184x10**22)/1000.0}**0.76
//
//   = 3.2x10**-7{ [(Mx/Ex)**-1]*4.184x10**19}**0.76  meters/second.
//
//   The specific energy E/M for this calculation should probably be
//   reduced by the specific binding energy for the asteroid,
//    [(3/5)G(M**2)/R]/M , which may be found in ergs/gr.
//
// Cratering: Crater Radius = 5.7 W**(1/3) meters, W = in tons TNT,
//                                       1 Ton TNT = 4.184x10**9 Joules.
//                                              W  = (1/2)m*v**2,
//                                    where  11.2 km/sec < v < 40 km/sec.
//
//  Asteroid diameters in meters: & According to ALLEN (Ast.Phys.Quan.)
//           Book A                       Book B   Earth's Ejectae Blanket (B)
//   Ceres - 20000                        380,000  1,230 Km < 1,242 Km
//   Pallas - 372000                      240,000  353 < 3,558 Km
//   Juno - 103000                        100,000  32.6 < 328.5 Km
//   Vesta - 195000                       240,000  353 < 3,558 Km
//   Hebe - 110000                        110,000  42 < 428
//   Iris - 100000                        100,000  32.6 < 328.5
//   Hygia - 160000                       160,000  117 < 1,180 Km
//   Eunomia - 140000                     140,000  81.5 < 821 Km
//   Psyche - 140000                      140,000  81.5 < 821 Km
//   Nemansa - 40000                       40,000  2.7 < 27 Km
// * 433 Eros (new probe observations)     40,000  2.7 < 27 Km
//                                                obs. via NEAR space probe.
//   Eros - 12000  (older tables)           7,000 23 < 236 meters
//   Davida - 130000                      130,000 66.6 < 670.8 Km
//   Achilles - 28000                            
//   Hidalgo - 18000
//   Amor - 3000                                 
//   Geographos - 1500                      1,500 0.355 < 3.57 meters 
//   Hermes - 1000                            300 0.448 cm < 4.47 cm 
//   Adonis - 1000                            150 
//   Apollo - 2000                            500 9.4 m < 94.65 meters
//   253 Mathilde - 53,000                 53,000
//
// * Chicxulub asteroid (from crater size)     7000 23.5 < 236.47 meters
// * Louis Alvarez' Cretaceous Model Asteroid 10000 62 < 624 meters
//   (The Dinosaur Extinction Asteroid Models)
//
//    The Alvarez diameter was computed from iridium concentrations.
//    Fallout from Krakatoa fell out in 3 to 6 months...but sunsets were
//    unusally colourful for 2 years. Alvarez believes that the extinction
//    of the dinosoars was due to a 2-year level of high dust in the
//    atmosphere, causing plant life to die, based on the fall time of
//    particles of dust at their terminal velocity in the atmosphere.
//    He reconned the explosion magnitude at <= 100 million megatons of TNT.
//
//    The actual associated crater was found in the Yucatan area, the 
//    Chicxulub crater of radius 161 Km, corresponding to an impact object
//    about the size of the asteroid Eros, 7 km wide, producing a crater
//    of 2.2 < depth < 4 kilometers, not deep enough to formally penetrate the
//    5 kilometer minimum earth crust thickness, producing a dust carpet
//    of thickness 23.5 to 236 meters for an impact of < 171 million megatons,
//    requiring 5.84x10**5 MT for asteroid vaporization prior to impact.
//    Thus Alvarez' model was really very close.
//
//    433 Eros is the table name for the new spaceprobe model for Eros,
//    which is about 40 Km wide. The Near-Earth Asteroid Rendevous probe NEAR
//    will rendevous with 433 Eros in February 1999, and may attempt a
//    landing on its surface after orbiting the asteroid.
//
//    Note meteor velocities up to 72 Km/sec have been witnessed. I compute
//    for Alvarez' 10 Km asteroid the maximum crater depth is greater than
//    the minimum earth crust thickness, so that sea organisms might boil.
//    Extinctions were initially timed from fossil studies at intervals
//    of about 26 million years, and crater studies show a periodicity of
//    about 28.5 million years, so that perhaps all massive extinctions have
//    been due to impacts of this type. I compute that 2 bombs of energy
//    about 425,000 megatons are required to destroy an asteroid of this
//    size, so that the 851,000 megaton vaporization energy must probably
//    be supplied by a larger number of bombs N of megatonage 851000/N.
//     (See Louis W. Alvarez, ALVAREZ: Adventures of a Physicist.)
//
//    The asteroid 433 Eros seems to be a threat of this type and should
//    probably be destroyed while we have command of nuclear means.(Green)
//    The dust carpet kicked up by 433 Eros would be 2.7 < 27 Km deep.
//    The destruction of 433 Eros will require about 54 million megatons.
//    December 1998 photos of 433 Eros include shots making it resemble
//    a lean man's head, somewhat reminescent of the stone heads of
//    Easter Island, or of software engineer Greg Yarnell, who was a hit here.
//    (Photos from the NEAR probe, which, having visited
//    asteroid 253 Mathilde, is on it's way to 433 Eros.) 433 Eros can
//    penetrate the 5 Km earth crust in some ocean areas, but not the
//    35 Km crust areas associated with the continents.
//     (Search INTERNET on "asteroid Eros", "NEAR", and "Yucatan crater".)
//
//   I note that perhaps dinosaurs complained of broken legs due to the
//   associated seismic shocks and also of sunami tidal wave effects.
//   The kinetic energy of a sunami tidal wave is proportional to it's
//   height and its velocity is c = (gh)**(1/2) where g is the accelleration
//   of gravity and h is the depth of the ocean, being 491 miles per hour
//   (0.22 kilometers per second) in seas 5 km deep, with wavelengths of
//   around 100 km and periods of 10-40 minutes with multiple wave crests.
//   As the shoreline is approached, sunami waves get higher.
//
//  Stone & Iron Proportions in Meteorites (after ALLEN)
//
//          Meteorites Seen     Meteorites Found   Density
// Irons          6%                66%            7.5-8   g per cm**3
// Stony-Iron     2%                 8%            5.5-6.0 g per cm**3
// Stone          92%               26%            3.0-3.5 g per cm**3
//
// Most probable size of meteorites found: Iron 15 Kg, Stone 3 Kg.
// Greatest known meteorite original mass: 8 x 10**4 Kg.
//
//
//  Meteor crater diameter, depth from rim, and depth from outer plane.
//   Diameter D in meters 1	10	100	1000	10000    100000
//   Depth from rim	0.12    2.7      27      180     1000      4700
//   Rim above plane            0.5       7       70      370      1200
//   Depth from plane H         2.2      20      110      630      3500
//
//  I compute that the depth from the plane H and the diameter D in meters
//  are related by H/D given approximately by the asyptotic form
//
//                  H/D  =  0.4332*[(1/1.9)**(log10[D])] for D > 10.
//
//  That is,  H/D = 0.4332 exp[ log10(D) * In(1/1.9) ]  for  D > 10,
//
//    and the error is not more than a factor of about 2 for 1 < D < 10. 
//                    
//
//  Meteor Craters               Diameter
//
//  Chicxulub, Yucatan        - 322000 meters  Dinosaur Extinction Asteroid
//  Clearwater Lakes, Quebec  -  26000 meters
//  Reiskessel, Barvaria      -  24000 meters
//  Deep Bay, Sask, Canada    -  13000 meters
//  Chubb, New Quebec, Canada -   3400 meters
//  Brent, Ontario, Canada    -   3200 meters
//  Barringer, Arizona, USA   -   1240 meters
//  Wolf Creek, Australia     -    820 meters
//
//  5 Km < Thickness of the Earth's crust < 35 Km.
//
//  The 5 Km crust thickness is found in some oceans.
//
//  The earthquake associated with impact would often be
//  extremely destructive.
//     Richter Scale - Characteristics of Quake        Max Ground
//      Magnitude                                         Acceleration
//       3.0          Detectable by Seismic Equipment Only
//       5.2          Strong. Some Damage.                     500 cm/s**2
//       6.8          Houses collapse.                        4000 cm/s**2
//       8.6          Catastrophic, total destruction.         100 m/s**2
//       8.9          Severest known terrestrial earthquake.
//
//    The total energy released in an earthquake of magnitude M on the
//    Richter scale is  E = 1.75x10**12 exp[3.32*M] ergs. Thus we might
//    define the Richter magnitude of an asteroid impact by using this
//    equation with E set to the asteroid impact energy in ergs, using
//    1 megaton = 4.2 x 10**22 ergs. Let E0 be the energy in megatons.
//    Then  M = (1/3.32)*In( E0*(4.2x10**22)/1.75x10**12 ) is the Richter
//    magnitude M of the asteroid impact. Simplifying,
//    M = 0.3012048*In[ E0*(2.4x10**10) ].
//
//      Richter_Magnitude               Characteristics
//                  3.0     Detectable with Seismic Equipment Only
//                  5.2     Strong.
//                  6.8     Houses Collapse.
//                  8.6     Catastrophic Quake
//                  8.9     Severest Earthquake
//                  9.0     
//                 10.0     Asteroid Hermes impact, 300 meters diameter.(Max) 
//                 11.0
//                 11.51    Asteroid Geographos impact, 1500 meters diam.(Max)
//                 12.0
//                 12.91    Chicxulub, Yucatan - Real Dinosoar Extinction     
//                 13.0     
//                 13.1     Alvarez Model Dinosaur Extinction Asteroid (Max)
//                 14.0    
//                 14.48    433 Eros - Death Star Asteroid (Max)
//                 15.0    
//                 16.51    Ceres - Largest Asteroid (Max)
//
//    Seismic wave velocity near the surface:
//      P-waves (longitudinal) - 8.11 Km/sec - At this rate, it would 
//        transverse a 6378 Km Earth radius in about 786 sec, 13.1 hours,
//          pentrate to the other side in approximately 26 hours.
//        Circles the world 40,074 Km in 40074/(2 * 8.11) = 2471 sec = 41 hr.
//          (Aftershocks). Actual propagation is somewhat different due to
//          the internal structure of the Earth.
//      S-waves (transverse) - 4.33 Km/sec (Aftershocks).
//      
//      An asteroid collision excites the 0S0 purely radial oscillation with
//      fundamental frequency of 57 minutes and harmonics 0S2, 0S3, 0S4,...
//      0SN,...  These oscillations take days to die out, with the
//      0S0 radial oscillation being the longest lived. That is, the
//      Earth rings like a bell. These are the spherical harmonics with
//      the azimuthal m = 0. 0S1 is not excited.(Stacy, PHYSICS OF THE EARTH)
//      Such global oscillations have been observed from large earthquakes.
//      This may have produced some seasick dinosoars....and stimulated
//      quite destructive secondary earthquakes.
//
//
// RESULTS FOR SELECT ASTEROIDS                  E=Total_Energy/2 for bombs
//                                                (Double for total energy=2E)
// D  Asteroid Radius   Crater_Radius Asteroid_Energy   Emelt    Evaporize
// S          (meters)  (Kilometers)  (Megatons)     (Megatons) (Megatons)
//
//   Ceres    380,000  7,358 < 17,191  < 2.74x10**13 1.4x10**10  2.34x10**10
//   Pallas   240,000  4,647 < 10,858  < 6.91x10**12 3.5x10**9   5.88x10**10
//   Juno     100,000  1,936 < 4,524   < 5x10**11    2.54x10**8  4.26x10**8
//   Vesta    240,000  4,647 < 10,858  < 6.91x10**12 3.52x10**9  5.88x10**10
//   Hebe     110,000  2,129 < 4,976   < 6.65x10**11 3.34x10**8  5.66x10**8 
//   Iris     100,000  1,936 < 4,524   < 5x10**11    2.54x10**8  5.26x10**8
//   Hygia    160,000  3,098 < 7,238   < 2x10**12    1.04x10**9  1.74x10**9
//   Eunomia  140,000  2,711 < 6,334   < 1.37x10**12 6.98x10**8  1.17x10**9
//   Psyche   140,000  2,711 < 6,334   < 1.37x10**12 6.98x10**8  1.17x10**9
//   Nemansa   40,000   774  < 1,810   < 32x10**9     1.63x10**7 2.72x10**7
// * 433 Eros  40,000   774  < 1,810   < 32x10**9     1.63x10**7 2.72x10**7
//    (433 Eros is a new model based on new measurements for Eros)
//   Eros       7,000   136 < 317     < 171x10**6    87,270      146,000
//   Davida   130,000  2,517 < 5,881  < 1.1x10**12   5.59x10**8  9.35x10**8 
//   Achilles   28000  542 < 1,267    < 1.1x10**10   5.9x10**6   9.34x10**6                            
//   Hidalgo    18000  359 < 814      < 2.9x10**9    1.484x10**6 2.48x10**6
//   Geographos  1500  29 < 68        < 1.69x10**6   859         1,440
//   Amor        3000  58 < 136       < 13.49x10**6  6,870       11,500
//   Hermes       300  5.8 < 13.6     < 13,499       6.87        11.49 
//   Apollo       500  97 < 226       < 62,497       31.8        53.19
//   Yucatan 
// *  Chicxulub  7000  136 < 317     < 171x10**6     87,270      291,928
// *   Alvarez  10000  194 < 452     < 499x10**6     2.54x10**5  4.26x10**5
//     The Dinosaur Extinction Asteroid
// *? 253 Mathilde 5300  1030 < 2400  < 7.44x10**10  3.79x10**7  6.34x10**7
//
//   And that's how the human race may destroy the asteroid Death Star * .
//
//   Comets with a density of 1 gr/cm**3 and comet nucleus width between
//   1 km and 10 km  may be destroyed by conventional nuclear weapons
//   with warheads in the range 18 Kilotons to 18 Megatons. In other words,
//   conventional nuclear weapons that can be transported with existing
//   systems should be adequate to destroy comets, although the problem
//   of finding the comet nucleus within the comet must be addressed by
//   the application hardware.
//
//                      - Author: James A. Green.
//			- Compiler: Borland C/C++
//                      - Date: December 30, 1998.
//
//
#include <stdio.h>
#include <math.h>
#include <string.h>
#include <stdlib.h>

main()
{
	int status;		// file status variable
	FILE *fp;		// file pointer.

	char value[50];        // Asteroid diam value in meters as FP string.
        double d;              // Asteroid diam after string conversion.
	double pi0 = 3.141592653589793;  //the known value of pi.
	double rad, diam,mass; // Asteroid radius, diameter, mass.
        double icedensity = 0.917e3; // density of ice  = 0.917x10**3, Kg/m**3.
	double icemass;        // Mass of icy comet of diameter d, Kg.
        double masscomet;      // = icemass.
        double pyritedensity = 5000.0; // iron pyrite density, Kg/m**3.
	double vap,melt;       // Vaporization and melting energies.
	double efrag;          // Fujiwara fragmentation energy.
	double rockthresh;   // Megaton rock shattering threshold, (Fujiwara).
	double icefrag;      // Megaton ice shattering threshold, (Fujiwara).
        double rocktolarge;  // Threshold - breaks rock to a few large pieces. 
	double megv, megm;   //vaporization megatonage, melting megatonage.
        double evap, emelt;  // vaporization & melting + grav binding energy.
	double ebind;        // gravitational binding energy in megatons of TNT.
        double ebindcomet;   // grav binding energy of ice comet in MT.
	double specificbind; // specific grav binding energy in ergs per gram.
	double s;            //    alternate variable for specificbind.
	double volume;       // asteroid volume in cubic meters.
        double vescape;      // escape velocity = sqrt[ 2GM/r ].
	double vejectv;      // Asteroid ejectae velocity, vaporized.
	double vejectm;      //  Asteroid ejectae velocity, melted.
        double vejectf;      //  Fujiwara fragmented asteroid ejectae velocity.
	double cratershape = 0.5;  // Crater shape volume form factor = 0.5.
//                        (Quadratic crater wall assumption y = ax**2 ).
	double fuji;         // Fujiwara energy to fragment in ergs/gr.
        double fujimtkg;     // Fujiwara energy to fragment in Megatons/Kg.
	double hmin;         //minimum crater depth = f(D)*D
//				= 0.4332 * D * exp[log10(D) * In(1/1.9)].
	double hmax;         // max crater depth.
	double rhoe= 2600.0; // mean density of the earth's crust, Kg/m**3.
	double rhop;   //  density of post-crater fallout in Kg/m**3.
	double vmin;   // minimum vol of displaced material before dust phase.
        double vmax;   // maximum vol of displaced material before dust phase.
	double dmassmin;  // minimum mass of material displaced from crater.
        double dmassmax;  // maximum mass of material displaced, Kg.
	double wmin;      // min dust carpet thickness over planet Earth.
	double wmax;      // max dust carpet thickness over planet Earth.
        double rearth = 637800.0;    // radius of the earth, 6378000 meters.
	double emin, emax; // emin = (1/2)*mass*(11200)**2 Joules,
//			      emax = (1/2)*mass*(40000)**2 Joules.
	double vm;   // temporary variable.
	double richtermin, richtermax; //min-max Richter Magnitude of Impact.
	double rmin, rmax; //asteroid impact crater radiusmin & max, meters.
	double dtkgpermt = 12.39; // deuterium+tritium   kg/megaton.
	double ddkgpermt = 12.1;  // deuterium+deuterium kg/megaton.
        double hlikgpermt = 29.23; // hydrogen+Lithium-6 kg/megaton.
	double shuttleloads; // number of shuttle loads required for reactants.
	double reactantmass; // reactantmass in Kg.
        double reactanttonage; // reactant weight in tons.
	double cuberoot(double x); // cube root  y = x**(1/3).
        double rootp75(double x);  // 3/4 root - y = x**0.75.
	
	int i;   // counter
	int sw;  // switch: exit main loop = 0, remain in main loop = 1.   

     sw = 1;
     fp = fopen("aster3.txt","w");
     while(sw == 1){
	printf("\nASTER3 - Compute Megatons E per weapon required to boil and\n");
	fprintf(fp,"\nASTER3 - Compute Megatons E per weapon required to boil and\n");
	printf("vaporize an asteroid of specific diameter, using a two-weapon\n");
	fprintf(fp,"vaporize an asteroid of specific diameter, using a two-weapon\n");
	printf("shock-wave pincher. Each bomb uses 1/2 of the asteroid\n");
	fprintf(fp,"shock-wave pincher. Each bomb uses 1/2 of the asteroid\n");
	printf("vaporization energy 2E for an asteroid composed of iron pyrites.\n");
	fprintf(fp,"vaporization energy 2E for an asteroid composed of iron pyrites.\n");
	printf("The bombs are to be mounted firmly in the surface. The program\n");
	fprintf(fp,"The bombs are to be mounted firmly in the surface. The program\n");
	printf("also gives the total stone asteroid catastrophic fragmentation energy\n");
	fprintf(fp,"also gives the total stone asteroid catastrophic fragmentation energy\n");
	printf("for shattering a stone asteroid to bits. For irregular\n");
	fprintf(fp,"for shattering a stone asteroid to bits. For irregular\n");
	printf("asteroids of volume V cubic meters, use d = 2*[(3V/4pi)**(1/3)].\n");
	fprintf(fp,"asteroids of volume V cubic meters, use d = 2*[(3V/4pi)**(1/3)].\n");
	printf("Note that the gravitational binding energy of the asteroid\n");
	fprintf(fp,"Note that the gravitational binding energy of the asteroid\n");
	printf("has been added to the total bomb energy and so escape velocity\n");
	fprintf(fp,"has been added to the total bomb energy and so escape velocity\n");
	printf("has been added to the Fujiwara-Tsukamoto ejectae velocity.\n");
	fprintf(fp,"has been added to the Fujiwara-Tsukamoto ejectae velocity.\n");
	printf("Typical icy comet nucleus width < 10 km. Add binding energy for comets.\n");
	fprintf(fp,"Typical icy comet nucleus width < 10 km. Add binding energy for comets.\n");
	printf(" Asteroid impact energy based on 11.2 km/sec < v < 40 km/sec\n");
	fprintf(fp," Asteroid impact energy based on 11.2 km/sec < v < 40 km/sec\n");
	printf(" SAMPLE ASTEROIDS                         FLOATING-POINT DIAMETER\n");
	fprintf(fp," SAMPLE ASTEROIDS                         FLOATING-POINT DIAMETER\n");
	printf("   Near-Earth 433 Eros                     d =  40000.0 meters\n");
	fprintf(fp,"   Near-Earth 433 Eros                     d =  40000.0 meters\n");
	printf("   Chicxulub Dinosoar Extinction Asteroid  d =   7000.0 meters\n");
	fprintf(fp,"   Chicxulub Dinosoar Extinction Asteroid  d =   7000.0 meters\n");
	printf("   Ceres  - Largest Asteroid -             d = 380000.0 meters\n");
	fprintf(fp,"   Ceres  - Largest Asteroid -             d = 380000.0 meters\n");
	printf("   Juno                                    d = 100000.0 meters\n");
	fprintf(fp,"   Juno                                    d = 100000.0 meters\n");
	printf("   Geographos                              d =   1500.0 meters\n");
	fprintf(fp,"   Geographos                              d =   1500.0 meters\n");
	printf("   Hermes - Small Asteroid -               d =    300.0 meters\n");
	fprintf(fp,"   Hermes - Small Asteroid -               d =    300.0 meters\n");
	printf("   Apollo                                  d =    500.0 meters\n");
	fprintf(fp,"   Apollo                                  d =    500.0 meters\n");
	printf("   Achilles                                d =  28000.0 meters\n");
	fprintf(fp,"   Achilles                                d =  28000.0 meters\n");
	printf("Output file: aster3.txt.\n");
	fprintf(fp,"Output file: aster3.txt.\n");
	printf(" Enter floating-point object diameter in meters: ");
	fprintf(fp," Enter floating-point object diameter in meters: ");
	scanf("%s",value);
	d = atof(value);
	rad = d/2.0;  // Cal asteroid radius in meters.
	printf("Entered %f\n\n",d);
	fprintf(fp,"Entered %f\n\n",d);

	   printf("ASTEROID DIAMETER,     MASS,         MEGATONAGE/PINCHER-BOMB\n");
	   fprintf(fp,"ASTEROID DIAMETER,     MASS,         MEGATONAGE/PINCHER-BOMB\n");

	   diam = 2.0*rad/1000.0;               // Cal diameter in Km.
           volume = (4.0*pi0/3.0)*rad*rad*rad;  // Asteroid volume,m**3
	   mass = pyritedensity*volume;         // Iron Pyrite Mass in Kg.
	   vescape = sqrt( 2.0*6.67e-11*mass/rad ); // escape velocity.
//                                            GRAVITATIONAL BINDING ENERGY
	   ebind = (3.0/5.0)*(6.67e-11)*mass*mass/rad; //binding energy in Joules.
           specificbind = (ebind*(1.0e7)/mass)/1000.0; // Ebind in ergs/gram.
	   ebind = ebind/4.184e15; // binding energy in megatons.
           
	   fuji = 5.0e8; //Fujiwara fragmentation energy in ergs/gram.
	   efrag = (mass*1000.0)*fuji; //Cal Fujiwara frag energy in ergs.
	   efrag = efrag/(4.184e22); // Cal Fujiwara frag energy in Megatons.   
	   vejectf = (3.2e-7)*rootp75( fuji ); // naked frag velocity.
           vejectf = vejectf + vescape; // add escape velocity.
//                vejectf is close to and less than ejectae velocity, m/sec.

//                 Other Fujiwara rock shattering thresholds

	   rockthresh = (mass*1000.0)*8.0e6/(4.184e22); // MT Shattering,rock.
	   rocktolarge = (5.0e5)*(mass*1000.0)/(4.184e22); // Rock to Few Frag
           icemass = volume*icedensity; // Mass of ice comet & MT threshold,
	   icefrag = (3.0e5)*(icemass*1000.0)/(4.184e22); // Ice Shattering.
	   
           masscomet = icemass; // compute comet mass
	   ebindcomet = (3.0/5.0)*(6.67e-11)*masscomet*masscomet/rad; // J
	   ebindcomet = ebindcomet/4.184e15; // Comet binding energy in MT.

	   emin = (1.0/2.0)*mass*(11200.0)*(11200.0); //asteroid energy
	   emax = (1.0/2.0)*mass*(40000.0)*(40000.0); //  in Joules.
	   emin = emin/4.189e9; // min asteroid impact energy, tons TNT.
	   emax = emax/4.189e9; // max asteroid impact energy, tons TNT.
	   rmin = 5.7*cuberoot( emin ); //min crater radius, meters.
	   rmax = 5.7*cuberoot( emax ); // max crater radius, meters.
	   hmin = rmin*(0.4332)*exp( log10(rmin)*log(1/1.9));
	   hmax = rmax*(0.4332)*exp( log10(rmax)*log(1/1.9));
	   vmin = 3.14159*rmin*rmin*hmin*cratershape; // minimum crater volume
	   vmax = 3.14159*rmax*rmax*hmax*cratershape; // maximum crater volume
	   rhop = (pi0/6.0)*rhoe; // Estimated dust density ejected by crater, kg/m**3,
//                                    spherical dust with cubic packing.
	   dmassmin = vmin*rhoe; // minimum crater mass ejected, Kg.
	   dmassmax = vmax*rhoe; // maximum crater mass ejected, Kg.
	   wmin = dmassmin/(4.0*3.14159*rearth*rearth*rhop); // Blanket
           wmax = dmassmax/(4.0*3.14159*rearth*rearth*rhop); //  thicknesses.

	   vap = mass/3.076e9; //asteroid boiling point energy, Megatons.
	   megv = vap/2.0;      // pincher bomb energy Evap to vaporize.
	   vm = rootp75( 4.184e19 ); // compute ejectae velocity limit.
	   vejectv = (3.2e-7)*vm*rootp75( vap/mass ); // < ejectae V.
	   vejectv = vejectv + vescape; // add escape velocity.

	   melt = mass/5.145e9; // asteroid melting point energy, Megatons
	   megm = melt/2.0;	// pincher bomb energy Emelt to melt.
           vm = rootp75( 4.184e19 ); // compute ejectae velocity limit.
	   vejectm = (3.2e-7)*vm*rootp75(melt/mass); // < ejectae V.
           vejectm = vejectm + vescape; // add escape velocity.

	   emin = emin/1.0e6;  //Tons TNT to Megatons TNT.
	   emax = emax/1.0e6;
	   richtermin = 0.3012048*log( emin*2.4e10 ); //Richter magnitude
	   richtermax = 0.3012048*log( emax*2.4e10 );

	   rmin = rmin/1000.0; // meters to Km.
	   rmax = rmax/1000.0;
	   hmin = hmin/1000.0; // convert meters to Km.
	   hmax = hmax/1000.0;

	   vejectv = 3.6*vejectv; //convert to km/hr
	   vejectm = 3.6*vejectm;
	   vejectf = 3.6*vejectf;

	   evap = megv + (ebind/2.0); // Add grav binding energy 
	   emelt = megm + (ebind/2.0);  //   to the pincher bomb energies.

	   megv = 2.0*megv + ebind;  // Include gravitational binding energy
	   megm = 2.0*megm + ebind;  //  in the total energy for vaporization,
           efrag = efrag + ebind;    //  melting, and catastropic fragmentation.

	   printf("D = %3.3f km, M = %e Kg, Evap = %e MT.[iron pyrite]\n", diam, mass, evap);
	   fprintf(fp,"D = %3.3f km, M = %e Kg, Evap = %e MT.[iron pyrite]\n", diam, mass, evap);
	   printf(" Icy CometMass = %e Kg     Emelt = %e MT.[iron]\n",masscomet, emelt);
	   fprintf(fp," Icy CometMass = %e Kg     Emelt = %e MT.[iron]\n",masscomet, emelt);
	   printf(" Asteroid Vaporization Energy + Ebind_grav   = %e MT.[pyrite]\n",2.0*megv);
	   fprintf(fp," Asteroid Vaporization Energy + Ebind_grav   = %e MT.[pyrite]\n",2.0*megv);
	   printf("   [Asteroid ejectae velocity about %e Km/hr.]\n", vejectv);
	   fprintf(fp,"   [Asteroid ejectae velocity about %e Km/hr.]\n", vejectv);
	   printf(" Asteroid Melting Point Energy + Ebind_grav  = %e MT.[iron]\n",2.0*megm);
	   fprintf(fp," Asteroid Melting Point Energy + Ebind_grav  = %e MT.[iron]\n",2.0*megm);
	   printf("   [Asteroid ejectae velocity about %e Km/hr.]\n", vejectm);
	   fprintf(fp,"   [Asteroid ejectae velocity about %e Km/hr.]\n", vejectm);
	   printf(" Asteroid Fragmentation Energy + Ebind_grav  = %e MT.[stone]\n", efrag);
	   fprintf(fp," Asteroid Fragmentation Energy + Ebind_grav  = %e MT.[stone]\n", efrag);
	   printf("   [Asteroid ejectae velocity about %e Km/hr.]\n", vejectf);
	   fprintf(fp,"   [Asteroid ejectae velocity about %e Km/hr.]\n", vejectf);
	   printf(" Asteroid Rock Shattering Threshold  E = %e MegaTons\n", rockthresh);
	   fprintf(fp," Asteroid Rock Shattering Threshold  E = %e MegaTons\n", rockthresh);
	   printf(" Asteroid Rock Break to a Few Pieces E = %e MegaTons\n", rocktolarge);
	   fprintf(fp," Asteroid Rock Break to a Few Pieces E = %e MegaTons\n", rocktolarge);
	   printf(" Comet Ice Fragmentation Threshold   E = %e MegaTons\n", icefrag);
	   fprintf(fp," Comet Ice Fragmentation Threshold   E = %e MegaTons\n", icefrag);
	   printf("  Ice-Silicate Fragmentation Threshold = %e MegaTons\n", 5.0*icefrag);
	   fprintf(fp,"  Ice-Silicate Fragmentation Threshold = %e MegaTons\n", 5.0*icefrag);
	   printf(" %e < Asteroid Impact Energy   < %e in MegaTons.\n",emin, emax);
	   fprintf(fp," %e < Asteroid Impact Energy   < %e in MegaTons.\n",emin, emax);
	   printf(" %e < Impact Richter Magnitude < %e\n",richtermin,richtermax);
	   fprintf(fp," %e < Impact Richter Magnitude < %e\n",richtermin,richtermax);
	   printf(" %e < Asteroid Crater Radius   < %e in Km.\n",rmin,rmax);
	   fprintf(fp," %e < Asteroid Crater Radius   < %e in Km.\n",rmin,rmax);
	   printf(" %e < Asteroid Crater Depth    < %e in Km.\n",hmin,hmax);
	   fprintf(fp," %e < Asteroid Crater Depth    < %e in Km.\n",hmin,hmax);
	   printf(" %e < Ejected Crater Mass      < %e in Kg.\n",dmassmin, dmassmax);
	   fprintf(fp," %e < Ejected Crater Mass      < %e in Kg.\n",dmassmin, dmassmax);
	   printf(" %e < Earth Dust Carpet        < %e meters.\n",wmin,wmax);
	   fprintf(fp," %e < Earth Dust Carpet        < %e meters.\n",wmin,wmax);
	   printf(" Densities:EarthCrust= %e, DustCarpet= %e, Kg/m**3.\n",rhoe,rhop);
	   fprintf(fp," Densities:EarthCrust= %e, DustCarpet= %e, Kg/m**3.\n",rhoe,rhop);
	   printf(" Asteroid Ebind_grav = %e MT, for comet = %e MT.\n", ebind, ebindcomet);
	   fprintf(fp," Asteroid Ebind_grav = %e MT, for comet = %e MT.\n", ebind, ebindcomet);

// If the min crater depth penetrates, don't print that max crater depth does.
	   if(hmin > 5.0 ){
	     printf(" Minimum crater depth > minimum Earth Crust Depth of 5 Km.\n");
	     fprintf(fp," Minimum crater depth > minimum Earth Crust Depth of 5 Km.\n");
           }
	   if(hmax > 5.0 && hmin < 5.0 ){
	     printf(" Maximum crater depth > minimum Earth Crust Depth of 5 Km.\n");
	     fprintf(fp," Maximum crater depth > minimum Earth Crust Depth of 5 Km.\n");
           }
	   if(hmin > 35.0 ){
	     printf(" Minimum crater depth > Earth Crust Depth of 35 Km.\n");
	     fprintf(fp," Minimum crater depth > Earth Crust Depth of 35 Km.\n");
           }
	   if(hmax > 35.0 && hmin < 35.0 ){
	     printf(" Maximum crater depth > Earth Crust Depth of 35 Km.\n");
	     fprintf(fp," Maximum crater depth > Earth Crust Depth of 35 Km.\n");
           }
	   printf("ENTER 0 TO EXIT, 1 TO REPEAT, 2 FOR REACTANT MASS & SHUTTLE LOADS: ");
	   fprintf(fp,"ENTER 0 TO EXIT, 1 TO REPEAT, 2 FOR REACTANT MASS & SHUTTLE LOADS: ");
	   scanf("%d",&sw);
	   if(sw == 2){

	       reactantmass = dtkgpermt*(2.0*megv); // total reactant mass, Kg.
	       reactanttonage = reactantmass*(2.205)/2000.0; // tons
	       shuttleloads = reactanttonage/27.5;
	       printf("\n DEUTERIUM-TRITIUM REACTANT MASSES AND SHUTTLE LOAD REQUIREMENTS\n\n");
	       fprintf(fp,"\n DEUTERIUM-TRITIUM REACTANT MASSES AND SHUTTLE LOAD REQUIREMENTS\n\n");
	       printf("Vaporization megatonage + Ebinding = %e MT.\n",megv);
	       fprintf(fp,"Vaporization megatonage + Ebinding = %e MT.\n",megv);
	       printf("               Weight of reactants = %e tons.\n", reactanttonage);
	       fprintf(fp,"               Weight of reactants = %e tons.\n", reactanttonage);
	       printf("               Space Shuttle loads = %e loads.\n", shuttleloads);
	       fprintf(fp,"               Space Shuttle loads = %e loads.\n", shuttleloads);
	       reactantmass = dtkgpermt*(2.0*megm); // total reactant mass, Kg.
	       reactanttonage = reactantmass*(2.205)/2000.0; // tons
	       shuttleloads = reactanttonage/27.5;
	       printf("Melting megatonage + Ebinding      = %e MT.\n",megm);
	       fprintf(fp,"Melting megatonage + Ebinding      = %e MT.\n",megm);
	       printf("               Weight of reactants = %e tons.\n", reactanttonage);
	       fprintf(fp,"               Weight of reactants = %e tons.\n", reactanttonage);
	       printf("               Space Shuttle loads = %e loads.\n", shuttleloads);
	       fprintf(fp,"               Space Shuttle loads = %e loads.\n", shuttleloads);
	       reactantmass = dtkgpermt*(2.0*efrag); // total reactant mass, Kg.
	       reactanttonage = reactantmass*(2.205)/2000.0; // tons
	       shuttleloads = reactanttonage/27.5;
	       printf("Fragmentation megatonage + Ebinding = %e MT.\n",efrag);
	       fprintf(fp,"Fragmentation megatonage + Ebinding = %e MT.\n",efrag);
	       printf("               Weight of reactants = %e tons.\n", reactanttonage);
	       fprintf(fp,"               Weight of reactants = %e tons.\n", reactanttonage);
	       printf("               Space Shuttle loads = %e loads.\n", shuttleloads);
	       fprintf(fp,"               Space Shuttle loads = %e loads.\n", shuttleloads);

	       reactantmass = dtkgpermt*(2.0*rockthresh); // total reactant mass, Kg.
	       reactanttonage = reactantmass*(2.205)/2000.0; // tons
	       shuttleloads = reactanttonage/27.5;
	       printf("Rock shattering threshold megatonage = %e MT.\n",rockthresh);
	       fprintf(fp,"Rock shattering threshold megatonage = %e MT.\n",rockthresh);
	       printf("               Weight of reactants = %e tons.\n", reactanttonage);
	       fprintf(fp,"               Weight of reactants = %e tons.\n", reactanttonage);
	       printf("               Space Shuttle loads = %e loads.\n", shuttleloads);
	       fprintf(fp,"               Space Shuttle loads = %e loads.\n", shuttleloads);

	       reactantmass = dtkgpermt*(2.0*rocktolarge); // total reactant mass, Kg.
	       reactanttonage = reactantmass*(2.205)/2000.0; // tons
	       shuttleloads = reactanttonage/27.5;
	       printf("Rock to Few large pieces megatonage = %e MT.\n",rocktolarge);
	       fprintf(fp,"Rock to Few large pieces megatonage = %e MT.\n",rocktolarge);
	       printf("               Weight of reactants = %e tons.\n", reactanttonage);
	       fprintf(fp,"               Weight of reactants = %e tons.\n", reactanttonage);
	       printf("               Space Shuttle loads = %e loads.\n", shuttleloads);

	       reactantmass = dtkgpermt*(2.0*icefrag); // total reactant mass, Kg.
	       reactanttonage = reactantmass*(2.205)/2000.0; // tons
	       shuttleloads = reactanttonage/27.5;
	       printf("Icy comet fragmentation threshold  = %e MT.\n",icefrag);
	       fprintf(fp,"Icy comet fragmentation threshold  = %e MT.\n",icefrag);
	       printf("               Weight of reactants = %e tons.\n", reactanttonage);
	       fprintf(fp,"               Weight of reactants = %e tons.\n", reactanttonage);
	       printf("               Space Shuttle loads = %e loads.\n", shuttleloads);
	       fprintf(fp,"               Space Shuttle loads = %e loads.\n", shuttleloads);

	       reactantmass = dtkgpermt*(2.0*ebind); // total reactant mass, Kg.
	       reactanttonage = reactantmass*(2.205)/2000.0; // tons
	       shuttleloads = reactanttonage/27.5;
	       printf("Asteroid Graviational Binding Energy = %e MT.\n",ebind);
	       fprintf(fp,"Asteroid Graviational Binding Energy = %e MT.\n",ebind);
	       printf("               Weight of reactants = %e tons.\n", reactanttonage);
	       fprintf(fp,"               Weight of reactants = %e tons.\n", reactanttonage);
	       printf("               Space Shuttle loads = %e loads.\n", shuttleloads);
	       fprintf(fp,"               Space Shuttle loads = %e loads.\n", shuttleloads);

	       printf("ENTER 0 TO EXIT, 1 TO RESTART, 3 FOR H+LITHIUM-6: ");
	       fprintf(fp,"ENTER 0 TO EXIT, 1 TO RESTART, 3 FOR H+LITHIUM-6: ");
	       scanf("%d",&sw);
	   }
	   if(sw == 3){

	       reactantmass = hlikgpermt*(2.0*megv); // total reactant mass, Kg.
	       reactanttonage = reactantmass*(2.205)/2000.0; // tons
	       shuttleloads = reactanttonage/27.5;
	       printf("\n HYDROGEN-LITHIUM-6 REACTANT MASSES AND SHUTTLE LOAD REQUIREMENTS\n\n");
	       fprintf(fp,"\n HYDROGEN-LITHIUM-6 REACTANT MASSES AND SHUTTLE LOAD REQUIREMENTS\n\n");
	       printf("Vaporization megatonage + Ebinding = %e MT.\n",megv);
	       fprintf(fp,"Vaporization megatonage + Ebinding = %e MT.\n",megv);
	       printf("               Weight of reactants = %e tons.\n", reactanttonage);
	       fprintf(fp,"               Weight of reactants = %e tons.\n", reactanttonage);
	       printf("               Space Shuttle loads = %e loads.\n", shuttleloads);
	       fprintf(fp,"               Space Shuttle loads = %e loads.\n", shuttleloads);

	       reactantmass = hlikgpermt*(2.0*megm); // total reactant mass, Kg.
	       reactanttonage = reactantmass*(2.205)/2000.0; // tons
	       shuttleloads = reactanttonage/27.5;
	       printf("Melting megatonage + Ebinding      = %e MT.\n",megm);
	       fprintf(fp,"Melting megatonage + Ebinding      = %e MT.\n",megm);
	       printf("               Weight of reactants = %e tons.\n", reactanttonage);
	       fprintf(fp,"               Weight of reactants = %e tons.\n", reactanttonage);
	       printf("               Space Shuttle loads = %e loads.\n", shuttleloads);
	       fprintf(fp,"               Space Shuttle loads = %e loads.\n", shuttleloads);

	       reactantmass = hlikgpermt*(2.0*efrag); // total reactant mass, Kg.
	       reactanttonage = reactantmass*(2.205)/2000.0; // tons
	       shuttleloads = reactanttonage/27.5;
	       printf("Fragmentation megatonage + Ebinding = %e MT.\n",efrag);
	       fprintf(fp,"Fragmentation megatonage + Ebinding = %e MT.\n",efrag);
	       printf("               Weight of reactants = %e tons.\n", reactanttonage);
	       fprintf(fp,"               Weight of reactants = %e tons.\n", reactanttonage);
	       printf("               Space Shuttle loads = %e loads.\n", shuttleloads);
	       fprintf(fp,"               Space Shuttle loads = %e loads.\n", shuttleloads);
	       reactantmass = hlikgpermt*(2.0*rockthresh); // total reactant mass, Kg.
	       reactanttonage = reactantmass*(2.205)/2000.0; // tons
	       shuttleloads = reactanttonage/27.5;
	       printf("Rock shattering threshold megatonage = %e MT.\n",rockthresh);
	       fprintf(fp,"Rock shattering threshold megatonage = %e MT.\n",rockthresh);
	       printf("               Weight of reactants = %e tons.\n", reactanttonage);
	       fprintf(fp,"               Weight of reactants = %e tons.\n", reactanttonage);
	       printf("               Space Shuttle loads = %e loads.\n", shuttleloads);
	       fprintf(fp,"               Space Shuttle loads = %e loads.\n", shuttleloads);

	       reactantmass = hlikgpermt*(2.0*rocktolarge); // total reactant mass, Kg.
	       reactanttonage = reactantmass*(2.205)/2000.0; // tons
	       shuttleloads = reactanttonage/27.5;
	       printf("Rock to Few large pieces megatonage = %e MT.\n",rocktolarge);
	       fprintf(fp,"Rock to Few large pieces megatonage = %e MT.\n",rocktolarge);
	       printf("               Weight of reactants = %e tons.\n", reactanttonage);
	       fprintf(fp,"               Weight of reactants = %e tons.\n", reactanttonage);
	       printf("               Space Shuttle loads = %e loads.\n", shuttleloads);
	       fprintf(fp,"               Space Shuttle loads = %e loads.\n", shuttleloads);

	       reactantmass = hlikgpermt*(2.0*icefrag); // total reactant mass, Kg.
	       reactanttonage = reactantmass*(2.205)/2000.0; // tons
	       shuttleloads = reactanttonage/27.5;
	       printf("Icy comet fragmentation threshold  = %e MT.\n",icefrag);
	       fprintf(fp,"Icy comet fragmentation threshold  = %e MT.\n",icefrag);
	       printf("               Weight of reactants = %e tons.\n", reactanttonage);
	       fprintf(fp,"               Weight of reactants = %e tons.\n", reactanttonage);
	       printf("               Space Shuttle loads = %e loads.\n", shuttleloads);
	       fprintf(fp,"               Space Shuttle loads = %e loads.\n", shuttleloads);

	       reactantmass = hlikgpermt*(2.0*ebind); // total reactant mass, Kg.
	       reactanttonage = reactantmass*(2.205)/2000.0; // tons
	       shuttleloads = reactanttonage/27.5;
	       printf("Asteroid Graviational Binding Energy = %e MT.\n",ebind);
	       fprintf(fp,"Asteroid Graviational Binding Energy = %e MT.\n",ebind);
	       printf("               Weight of reactants = %e tons.\n", reactanttonage);
	       fprintf(fp,"               Weight of reactants = %e tons.\n", reactanttonage);
	       printf("               Space Shuttle loads = %e loads.\n", shuttleloads);
	       fprintf(fp,"               Space Shuttle loads = %e loads.\n", shuttleloads);
	       printf("ENTER 0 TO EXIT, 1 TO RESTART: ");
	       fprintf(fp,"ENTER 0 TO EXIT, 1 TO RESTART: ");
	       scanf("%d",&sw);
	   }
     }
     printf("\nEXIT, Output report file aster3.txt.\n");
     fprintf(fp,"\nEXIT, Output report file aster3.txt.\n");
     status = fclose(fp);
     exit(0);
}
//
// cuberoot(x) for  x > 1.0.
//
double cuberoot(double x)
{
	double start, ending, mid;
	int i;

	start = 0.0;
	ending = x;
	mid = (ending + start)/2.0;
	for(i = 1; i < 300; i++){
	   if( mid*mid*mid > x){
	      ending = mid;
	      mid = (start + ending)/2.0;
	   }
	   else if (mid*mid*mid < x){
	      start = mid;
	      mid = (start + ending)/2.0;
           }
	}
	return( mid );  
}
//
// rootp75(x) - y = x**0.75
//
double rootp75(double x)
{
      double y;
      double z;
//
// DOMAIN ERROR: LOG -  y = sqrt(x) fails for Ceres large diameter.
//      y = sqrt(x); fails, try instead y = exp((1/2)log x), also fails.
//
//      z = x/1000000.0;      // This domain-shrinking trick also fails:
//      y = sqrt(z);          // so try reducing the range of x, then
//      y = y*sqrt( 1000000.0 );   // correct afterwards with a multiply.
//      The problem was that the fuji energy was less than the specific
//      binding energy per gram of Ceres, so that the argument was < 0.0!!!
//
//
      y = sqrt(x);
      y = sqrt(y);
      y = y*y*y;

      return(y);
}
//
//  REFERENCES
//
// [1] Binzel, Gehrls, Matthews, ASTEROIDS II, The University of Arizona
//     Press, 1989.
// [2]  Fujiwara, et.al., "Experiments and Scaling Laws on Catastropic 
//     Collisons in ASTEROIDS II, edited by Binzel, Gehrls and Matthews, 
//     University of Arizona Press, 1989, page 240.
// [3] Stacy, Frank D., PHYSICS OF THE EARTH, John Wiley & Sons, 1969.
// [4] Dodd, Robert T., THUNDERSTONES AND SHOOTING STARS, Harvard
//     University Press, 1986.
// [5] Sears, D.W., THE NATURE AND ORIGIN OF METEORITES, Oxford, 1978.
// [6] CRC HANDBOOK OF CHEMISTRY AND PHYSICS.
// [7] Green, James A., THE EFFECTS OF THERMONUCLEAR WEAPONS, 4th edition,
//     1999 state, Greenwood Research. Includes nuclear effects and
//     asteroid destruction software.
// [8] Gross, Robert A., FUSION ENERGY, John Wiley and Sons.
//     Gross' excellent material on fusion reactions allows one to calculate
//     the minimum reactant weights necessary in asteroid destruction
//     problems. I note that the space shuttle capacity is 27.5 tons.
//     Thousands of space shuttle flights would be required for 433 Eros
//     or 253 Mathilde, which may motovate the construction of larger
//     spacecraft. Only one load would do for the asteroid Hermes.
// [9] Glasstone & Dolan, THE EFFECTS OF NUCLEAR WEAPONS, U.S. Government
//     Printing Office.
// [10] Sagan, Carl, and Anne Druyan, THE COMET.
// [11] Swamy, K.S.Krishna, PHYSICS OF COMETS, World Scientific, 1986.
//
//
