//
//      orbit.cpp -  Calculate the orbital perturbation of an asteroid
//                   due to a nuclear explosion of energy E.
//
//      OUTPUT FILE: orbit.txt, Oct. 2001
//
//      For simplicity, consider a stone asteroid of diameter d
//      in a circular orbit with a radius equal to the radius of the
//      earth's orbit around the sun. Explode the bomb so that the normal
//      vector to the crater is tangent to the velocity vector associated
//      with the asteroid motion.  Give the orbital change delta_R
//      in earth radii in the orbital radius.  For safety, this should
//      be > 2*R_earth.
//
//      Consider that the explosion excavates a crater of volume V_crater
//      with material density = density.  Then if v_ejectae is the velocity
//      of ejectae in the spherical cap associated with the ejection,
//      E_bomb = (1/2)*(V_crater * density)*(v_ejectae)**2, neglecting
//      gravitational binding energy.  We may use
//        E_bomb - E_binding = (1/2)(V_crater * density)*(v_ejectae)**2,
//      where
//                 E_binding = (G*M/R)*density*V_crater,
//
//      where M is the mass of the asteroid and R is it's radius.
//      Then
//          v_ejectae = [ 2*(E_bomb - E_binding)/(density*V_crater)]**(1/2).
//
//      Normal to the crater, delta_p < v_ejectae*M_crater(E).
//
//      Averaging over the spherical cap of ejection angles, it is
//      approximately true that the net momentum change is
//
//             delta_p = [0.7071]*v_ejectae*M_crater(E),
//
//      where     M_crater(E) = density*V_crater(E)
//      is the mass ejected from the crater by a bomb
//      of energy E. This is in a direction tangent to the asteroid
//      orbital velocity and opposing it.  For our simple circular orbit,
//
//      GM_sun/R**2 = (v**2)/R = (L**2)/(m**2 R**3), so that
//
//         R = (L**2)/(m**2 G*M), where m is the asteroid mass.
//
//      Then R_new = [(L - delta_L)**2]/(m**2 G*M), so that
//
//         delta_R = R - R_new.
//
//      Note that the inertial drift velocity v_drift = -delta_p/mass.
//      
//      1 Megaton = 4.184 x 10**15 Joules.
//      Density of iron pyrites = 5000 kg/m**3.
//      Density of stone = 3500 kg/m**3 (typical).
//
//      The problem with our argument is that the dimensions of the
//      crater dug by the bomb of energy E probably depend on the exact
//      composition of the asteroid.  The cratering law we employ
//      is the one used for cratering on the surface of the Earth,
//      the Moon, Mars, Venus, Mercury, and similar bodies. So these
//      results should be regarded as approximate only.
//
//
//  MELTING AND BOILING VAPORIZATION PARAMETERS FOR KEY ELEMENTS
//                                                    Approximated
// Element    Melting   Boiling  Heat Capacity  Boil Energy  Boiling Coeff.
//             Temp (K)   Temp (K)    J/Kg*K        J/Kg     Kg/Megaton
// Silicon    1687       3540        705      2.4957x10**6  1.6765x10**9
// Aluminum    934       2793        897      2.5053x10**6  1.6700x10**9
// Iron       1811       3135        449      1.4076x10**6  2.9724x10**9
// Tungsten   3695       5828        132      0.7693x10**6  5.4387x10**9
// Platinum   2042       4100        133      0.5453x10**6  7.6728x10**9
// Zirconium  2128       4682        278      1.3016x10**6  3.2145x10**9
//
//
// Cratering: Crater Radius = 5.7 W**(1/3) meters, W = in tons TNT,
//                                       1 Ton TNT = 4.184x10**9 Joules.
//
//  Asteroid diameters in meters: & According to ALLEN (Ast.Phys.Quan.)
//           Book A                       Book B   Earth's Ejectae Blanket (B)
//   Ceres - 20000                        380,000  1,230 Km < 1,242 Km
//   Pallas - 372000                      240,000  353 < 3,558 Km
//   Juno - 103000                        100,000  32.6 < 328.5 Km
//   Vesta - 195000                       240,000  353 < 3,558 Km
//   Hebe - 110000                        110,000  42 < 428
//   Iris - 100000                        100,000  32.6 < 328.5
//   Hygia - 160000                       160,000  117 < 1,180 Km
//   Eunomia - 140000                     140,000  81.5 < 821 Km
//   Psyche - 140000                      140,000  81.5 < 821 Km
//   Nemansa - 40000                       40,000  2.7 < 27 Km
// * 433 Eros (new probe observations)     40,000  2.7 < 27 Km
//                                                obs. via NEAR space probe.
//   Eros - 12000  (older tables)           7,000 23 < 236 meters
//   Davida - 130000                      130,000 66.6 < 670.8 Km
//   Achilles - 28000                            
//   Hidalgo - 18000
//   Amor - 3000                                 
//   Geographos - 1500                      1,500 0.355 < 3.57 meters 
//   Hermes - 1000                            300 0.448 cm < 4.47 cm 
//   Adonis - 1000                            150 
//   Apollo - 2000                            500 9.4 m < 94.65 meters
//   253 Mathilde - 53,000                 53,000
//
// * Chicxulub asteroid (from crater size)     7000 23.5 < 236.47 meters
// * Louis Alvarez' Cretaceous Model Asteroid 10000 62 < 624 meters
//   (The Dinosaur Extinction Asteroid Models)
//

//  Stone & Iron Proportions in Meteorites (after ALLEN)
//
//          Meteorites Seen     Meteorites Found   Density
// Irons          6%                66%            7.5-8   g per cm**3
// Stony-Iron     2%                 8%            5.5-6.0 g per cm**3
// Stone          92%               26%            3.0-3.5 g per cm**3
//
// Most probable size of meteorites found: Iron 15 Kg, Stone 3 Kg.
// Greatest known meteorite original mass: 8 x 10**4 Kg.
//
//
//  Meteor crater diameter, depth from rim, and depth from outer plane.
//   Diameter D in meters 1	10	100	1000	10000    100000
//   Depth from rim	0.12    2.7      27      180     1000      4700
//   Rim above plane            0.5       7       70      370      1200
//   Depth from plane H         2.2      20      110      630      3500
//
//  I compute that the depth from the plane H and the diameter D in meters
//  are related by H/D given approximately by the asyptotic form
//
//                  H/D  =  0.4332*[(1/1.9)**(log10[D])] for D > 10.
//
//  That is,  H/D = 0.4332 exp[ log10(D) * In(1/1.9) ]  for  D > 10,
//
//    and the error is not more than a factor of about 2 for 1 < D < 10. 
//                    
//
//                      - Author: James A. Green.
//			- Compiler: Borland C/C++
//                      - Date: February 1, 1999.
//
//
#include <stdio.h>
#include <math.h>
#include <string.h>
#include <stdlib.h>

main()
{
	int status;		// file status
	FILE *fp;		// file pointer

	char value[50];        // Asteroid diam value in meters as FP string.
	double d;              // Asteroid diam after string conversion.
	double e;	       // Bomb energy E to perturb orbit, and
        double megatons;       //   in megatons.
	double rearth = 6378000.0;      // Earth's radius in meters.
	double rearthorbit = 1.49e11; // Radius of earth's solar orbit,meters.
	double r;		// Explosion crater radius = r(e).
        double h;		// Explosion crater depth = h(e).
	double v;		// Explosion crater volume = v(e).
	double cratershape = 0.5; // Assume quadratic crater walls y = a*x**2.
	double cratermass;      // Crater stuffings mass = density*v.
	double ebind;           // Crater mass bind energy to asteroid.
	double delta_p;		// Change in momentum due to explosion.
	double delta_r;		// Change in the asteroid orbit radius.
	double percent;         // Per cent change in orbital radius.
	double rorbit;		// Asteroid orbit radius in meters.
        double erorbit;         // Asteroid orbit radius in earth radii.
	double rneworbit;       // New asteroid orbit radius after explosion.
	double l_orbit;         // Orbit angular momentum.
	double delta_l;		// Change in orbital angular momentum.
        double v_drift;   	// Inertial drift velocity v = -delta_p/mass.
	double G = 6.67e-11;    // Newton's gravitation constant.
	double msun = 1.99e30;	// Mass of the Sun in kilograms.       

	double pi0 = 3.141592653589793; //the known value of pi.

	double rad, diam,mass; 		// Asteroid radius, diameter, mass.
	double volume;			// Asteroid volume in m**3.	
	double pyritedensity = 5000.0; 	// iron pyrite density, Kg/m**3.
	double stonyirondensity = 6000.0; // stony-iron density, Kg/m**3.
        double stonedensity = 3500.0;   // density of stone.
	double density; 		// asteroid density.

	double cuberoot(double x); // cube root  y = x**(1/3).
        double rootp75(double x);  // 3/4 root - y = x**0.75.
	
	int i;   // counter
	int sw;  // switch: exit main loop = 0, remain in main loop = 1.   

     sw = 1;
     fp = fopen("orbit.txt", "w");
     while(sw == 1){
	printf("\nORBIT - Compute the orbital perturbation of an asteroid\n");
	fprintf(fp,"\nORBIT - Compute the orbital perturbation of an asteroid\n");
	printf("circular orbit with an orbital radius equal to the earth's\n");
	fprintf(fp,"circular orbit with an orbital radius equal to the earth's\n");
	printf("radius. Also computes the induced drift velocity.\n");
	fprintf(fp,"radius. Also computes the induced drift velocity.\n");
	printf("The asteroid of diameter d is assumed to be of stone\n");
	fprintf(fp,"The asteroid of diameter d is assumed to be of stone\n");
	printf("composition. We assume the perturbation is a blast of\n");
	fprintf(fp,"composition. We assume the perturbation is a blast of\n");
	printf("E megatons placed so that the normal to the crater is tangent\n");
	fprintf(fp,"E megatons placed so that the normal to the crater is tangent\n");
	printf("to the orbital velocity, so that the effect is to shrink\n");
	fprintf(fp,"to the orbital velocity, so that the effect is to shrink\n");
	printf("the orbit. Induced drift may apply to other geometries.\n");
	fprintf(fp,"the orbit. Induced drift may apply to other geometries.\n");
	printf("The program queries for the asteroid diameter and the\n");
	fprintf(fp,"The program queries for the asteroid diameter and the\n");
	printf("bomb-energy E and computes the circular orbit change delta_R\n");
	fprintf(fp,"bomb-energy E and computes the circular orbit change delta_R\n");
	printf("in earth radii, also giving the drift velocity v = -delta_p/mass.\n");
	fprintf(fp,"in earth radii, also giving the drift velocity v = -delta_p/mass.\n");
	printf("This gives you some feel for how many megatons is required.\n");
	fprintf(fp,"This gives you some feel for how many megatons is required.\n");
	printf("\n Enter floating-point asteroid diameter in meters: ");
	fprintf(fp,"\n Enter floating-point asteroid diameter in meters: ");
	scanf("%s",value);
	d = atof(value);
	rad = d/2.0;  // Cal asteroid radius in meters.
	printf(" Entered %f.",d);
	fprintf(fp," Entered %f.",d);
	printf("\n Enter floating-point bomb energy in megatons: ");
	fprintf(fp,"\n Enter floating-point bomb energy in megatons: ");
	scanf("%s",value);
	e = atof(value);	
	printf(" Entered %f.\n\n",e);
	fprintf(fp," Entered %f.\n\n",e);


	   megatons = e;    // bomb energy in megatons.  

	   diam = 2.0*rad/1000.0;               // Cal diameter in Km.
	   volume = (4.0*pi0/3.0)*rad*rad*rad;  // Asteroid volume,m**3
	   density = stonedensity;		// Trial density in kg/m**3
	   mass = density*volume;         	// Asteroid Mass in Kg.
	   
	   e = e*(1.0e6); // min explosion energy, tons TNT.
	   	  
	   r = 5.7*cuberoot( e ); // crater radius r(e), meters.
	   h = r*(0.4332)*exp( log10(r)*log(1/1.9));  // crater depth,meters.
	   v = 3.14159*r*r*h*cratershape; //  crater volume v(e).
           cratermass = density*v;        //  crater stuffings mass.

	   e = e*4.184e9;    // Explosion energy in Joules.
	   ebind = G*mass*cratermass/rad;  // binding E of crater mass to asteroid.

	   delta_p = (0.7071)*sqrt( 2.0*density*v*(e - ebind)); //momentum change.
	   v_drift = -delta_p/mass; // calculate intertial drift induced.
	   v_drift = (v_drift/rearth)*60.0*60.0; // in earth radii per hour.

	   rorbit = rearthorbit; // asteroid orbit = earth orbit.
	   l_orbit = mass*(sqrt( G*msun*rorbit ));
	   delta_l = delta_p*rorbit;
	   rneworbit = (l_orbit - delta_l)*(l_orbit - delta_l);
	   rneworbit = rneworbit/(mass*mass*G*msun);

	   delta_r = rorbit - rneworbit; // Find change in orbit radius.
           delta_r = delta_r/rearth;       //   in Earth radii.
	   erorbit = rorbit/rearth;      // Asteroid orbit in earth radii.
           percent = (delta_r/erorbit)*100.0; // Per cent change.

	   printf(" ASTEROID DIAMETER = %e kilometers.\n", diam);
	   fprintf(fp," ASTEROID DIAMETER = %e kilometers.\n", diam);
	   printf(" ORBIT RADIUS      = %e earth radii.\n", erorbit);
	   fprintf(fp," ORBIT RADIUS      = %e earth radii.\n", erorbit);
	   printf(" ASTEROID MASS     = %e kilgrams.\n", mass);
	   fprintf(fp," ASTEROID MASS     = %e kilgrams.\n", mass);
	   printf(" BOMB ENERGY       = %e megatons.\n", megatons);
	   fprintf(fp," BOMB ENERGY       = %e megatons.\n", megatons);
	   printf(" -> DELTA_RADIUS   = %e earth radii.\n", delta_r);
	   fprintf(fp," -> DELTA_RADIUS   = %e earth radii.\n", delta_r);
	   printf("                   = %f percent change.\n", percent);
	   fprintf(fp,"                   = %f percent change.\n", percent);
	   printf(" -> DRIFT VELOCITY = %e earth radii/hour\n",v_drift);
	   fprintf(fp," -> DRIFT VELOCITY = %e earth radii/hour\n",v_drift);
	   printf("                   = %e earth radii/day\n",v_drift*24.0);
	   fprintf(fp,"                   = %e earth radii/day\n",v_drift*24.0);
	   printf("                   = %e earth radii/month\n\n",v_drift*24.0*30.0);
	   fprintf(fp,"                   = %e earth radii/month\n\n",v_drift*24.0*30.0);

	   printf("ENTER 0 TO EXIT, 1 TO REPEAT: ");
	   fprintf(fp,"ENTER 0 TO EXIT, 1 TO REPEAT: ");
	   scanf("%d",&sw);
	   
     }
     printf("\nEXIT, Output report file orbit.txt.\n");
     fprintf(fp,"\nEXIT, Output report file orbit.txt.\n");
     status = fclose(fp);
     exit(0);
}
//
// cuberoot(x) for  x > 1.0.
//
double cuberoot(double x)
{
	double start, ending, mid;
	int i;

	start = 0.0;
	ending = x;
	mid = (ending + start)/2.0;
	for(i = 1; i < 300; i++){
	   if( mid*mid*mid > x){
	      ending = mid;
	      mid = (start + ending)/2.0;
	   }
	   else if (mid*mid*mid < x){
	      start = mid;
	      mid = (start + ending)/2.0;
           }
	}
	return( mid );  
}
//
// rootp75(x) - y = x**0.75
//
double rootp75(double x)
{
      double y;
      double z;
//
// DOMAIN ERROR: LOG -  y = sqrt(x) fails for Ceres large diameter.
//      y = sqrt(x); fails, try instead y = exp((1/2)log x), also fails.
//
//      z = x/1000000.0;      // This domain-shrinking trick also fails:
//      y = sqrt(z);          // so try reducing the range of x, then
//      y = y*sqrt( 1000000.0 );   // correct afterwards with a multiply.
//      The problem was that the fuji energy was less than the specific
//      binding energy per gram of Ceres, so that the argument was < 0.0!!!
//
//
      y = sqrt(x);
      y = sqrt(y);
      y = y*y*y;

      return(y);
}
//
//  REFERENCES
//
// [1] Binzel, Gehrls, Matthews, ASTEROIDS II, The University of Arizona
//     Press, 1989.
// [2]  Fujiwara, et.al., "Experiments and Scaling Laws on Catastropic 
//     Collisons in ASTEROIDS II, edited by Binzel, Gehrls and Matthews, 
//     University of Arizona Press, 1989, page 240.
// [3] Stacy, Frank D., PHYSICS OF THE EARTH, John Wiley & Sons, 1969.
// [4] Dodd, Robert T., THUNDERSTONES AND SHOOTING STARS, Harvard
//     University Press, 1986.
// [5] Sears, D.W., THE NATURE AND ORIGIN OF METEORITES, Oxford, 1978.
// [6] CRC HANDBOOK OF CHEMISTRY AND PHYSICS.
// [7] Green, James A., THE EFFECTS OF THERMONUCLEAR WEAPONS, 4th edition,
//     1999 state, Greenwood Research. Includes nuclear effects and
//     asteroid destruction software.
// [8] Gross, Robert A., FUSION ENERGY, John Wiley and Sons.
//     Gross' excellent material on fusion reactions allows one to calculate
//     the minimum reactant weights necessary in asteroid destruction
//     problems. I note that the space shuttle capacity is 27.5 tons.
//     Thousands of space shuttle flights would be required for 433 Eros
//     or 253 Mathilde, which may motovate the construction of larger
//     spacecraft. Only one load would do for the asteroid Hermes.
// [9] Glasstone & Dolan, THE EFFECTS OF NUCLEAR WEAPONS, U.S. Government
//     Printing Office.
// [10] Sagan, Carl, and Anne Druyan, THE COMET.
// [11] Swamy, K.S.Krishna, PHYSICS OF COMETS, World Scientific, 1986.
//
//
